@@ -18,7 +18,7 @@ class Watcher:
     @staticmethod
     async def _print_process(process):
         while True:
-            line = (await process.stdout.readline()).decode()
+            line = (await process.stdout.readline()).decode().strip()
             if not line:
                 break
             print(line)
